package com.fs.live.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.live.domain.Live;

/**
 * 直播Mapper接口
 * 
 * @author fs
 * @date 2025-01-17
 */
public interface LiveMapper extends BaseMapper<Live>
{
    /**
     * 查询直播
     * 
     * @param liveId 直播主键
     * @return 直播
     */
    public Live selectLiveByLiveId(Long liveId);

    /**
     * 查询直播列表
     * 
     * @param live 直播
     * @return 直播集合
     */
    public List<Live> selectLiveList(Live live);

    /**
     * 新增直播
     * 
     * @param live 直播
     * @return 结果
     */
    public int insertLive(Live live);

    /**
     * 修改直播
     * 
     * @param live 直播
     * @return 结果
     */
    public int updateLive(Live live);

    /**
     * 删除直播
     * 
     * @param liveId 直播主键
     * @return 结果
     */
    public int deleteLiveByLiveId(Long liveId);

    /**
     * 批量删除直播
     * 
     * @param liveIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLiveByLiveIds(Long[] liveIds);
}
